# Receptorctl Test Docs

The receptorctl test docs are fairly limited and aim to specifically test the
receptorctl interface rather than test receptor itself. These tests are limited
but appropriate to test the python client for receptor for any projects that
may use it. I think the tests are fairly self explanatory so I will not provide
any detail on how they work.
